@@ -1,7 +1,7 @@
 package App::WHOGrowthReferenceUtils;
 
-our $DATE = '2018-08-26'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2021-01-03'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Utilities related to WHO growth reference
@@ -18,7 +18,7 @@ App::WHOGrowthReferenceUtils - Utilities related to WHO growth reference
 
 =head1 VERSION
 
-This document describes version 0.001 of App::WHOGrowthReferenceUtils (from Perl distribution App-WHOGrowthReferenceUtils), released on 2018-08-26.
+This document describes version 0.002 of App::WHOGrowthReferenceUtils (from Perl distribution App-WHOGrowthReferenceUtils), released on 2020-01-03.
 
 =head1 DESCRIPTION
 
@@ -40,7 +40,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-WHOGrowthReferen
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-WHOGrowthReferenceUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-WHOGrowthReferenceUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -56,7 +56,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
